# Changelog

All notable changes to this project will be documented in this file.

## [0.1.2](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.1...v0.1.2) (2026-03-21)


### Bug Fixes

* handle invalid split regex in python bindings ([#7](https://github.com/zhixiangli/fast-bpe-rs/issues/7)) ([151d0c1](https://github.com/zhixiangli/fast-bpe-rs/commit/151d0c17c1f40d127cb74dd7de69fe2324603a4b))
* normalize python unicode decode errors ([#9](https://github.com/zhixiangli/fast-bpe-rs/issues/9)) ([0d4c063](https://github.com/zhixiangli/fast-bpe-rs/commit/0d4c063080ade3919c12823d32529371f4da240b))

## [0.1.1](https://github.com/zhixiangli/fast-bpe-rs/compare/v0.1.0...v0.1.1) (2026-03-21)


### Bug Fixes

* handle invalid split regex in python bindings ([#7](https://github.com/zhixiangli/fast-bpe-rs/issues/7)) ([151d0c1](https://github.com/zhixiangli/fast-bpe-rs/commit/151d0c17c1f40d127cb74dd7de69fe2324603a4b))
* normalize python unicode decode errors ([#9](https://github.com/zhixiangli/fast-bpe-rs/issues/9)) ([0d4c063](https://github.com/zhixiangli/fast-bpe-rs/commit/0d4c063080ade3919c12823d32529371f4da240b))

## [0.1.0] - 2026-03-21

### Miscellaneous Chores

* Initial release.
